@@ -1,8 +1,8 @@
 APP = 'apigeecli'
 CMD = 'apigee'
-__version__ = '0.42.3'
-description = 'Apigee Management API command-line interface with multi-factor authentication'
-long_description = """Apigee Management API command-line interface with multi-factor authentication"""
+__version__ = '0.44.0'
+description = 'Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support'
+long_description = """Apigee Management API command-line interface with multi-factor authentication (MFA) and single sign-on (SSO)/SAML support"""
 
 import json
 from os import getenv
@@ -17,8 +17,13 @@ APIGEE_ADMIN_API_URL = 'https://api.enterprise.apigee.com'
 APIGEE_OAUTH_URL = 'https://login.apigee.com/oauth/token'
 APIGEE_ZONENAME_OAUTH_URL = 'https://{zonename}.login.apigee.com/oauth/token'
 APIGEE_ZONENAME = getenv('APIGEE_ZONENAME')
+APIGEE_CLI_IS_MACHINE_USER = True if getenv('APIGEE_CLI_IS_MACHINE_USER') in (True, 'True', 'true', '1') else False
+APIGEE_SAML_LOGIN_URL = 'https://{zonename}.login.apigee.com/passcode'
 APIGEE_ORG = getenv('APIGEE_ORG')
 
+# crypto
+APIGEE_CLI_SYMMETRIC_KEY = getenv('APIGEE_CLI_SYMMETRIC_KEY')
+
 # custom
 APIGEE_CLI_AUTHORIZATION_DEVELOPER_ATTRIBUTE = 'team'
 APIGEE_CLI_PREFIX = getenv('APIGEE_CLI_PREFIX')
