@@ -15,8 +15,8 @@ def caches():
     pass
 
 
-def _clear_all_cache_entries(username, password, mfa_secret, org, profile, name, environment, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).clear_all_cache_entries(environment).text
+def _clear_all_cache_entries(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).clear_all_cache_entries(environment).text
 
 
 @caches.command(help='Clears all cache entries.')
@@ -29,8 +29,8 @@ def clear(*args, **kwargs):
     console.echo(_clear_all_cache_entries(*args, **kwargs))
 
 
-def _clear_a_cache_entry(username, password, mfa_secret, org, profile, name, environment, entry, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).clear_a_cache_entry(environment, entry).text
+def _clear_a_cache_entry(username, password, mfa_secret, token, zonename, org, profile, name, environment, entry, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).clear_a_cache_entry(environment, entry).text
 
 
 @caches.command(help='Clears a cache entry, which is identified by the full CacheKey prefix and value.')
@@ -44,8 +44,8 @@ def clear_entry(*args, **kwargs):
     console.echo(_clear_a_cache_entry(*args, **kwargs))
 
 
-def _create_a_cache_in_an_environment(username, password, mfa_secret, org, profile, name, environment, body, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).create_a_cache_in_an_environment(environment, body).text
+def _create_a_cache_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_a_cache_in_an_environment(environment, body).text
 
 
 @caches.command(
@@ -61,8 +61,8 @@ def create(*args, **kwargs):
     console.echo(_create_a_cache_in_an_environment(*args, **kwargs))
 
 
-def _get_information_about_a_cache(username, password, mfa_secret, org, profile, name, environment, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).get_information_about_a_cache(environment).text
+def _get_information_about_a_cache(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_information_about_a_cache(environment).text
 
 
 @caches.command(help='Gets information about a cache. The response might contain a property named persistent. That property is no longer used by Edge.')
@@ -75,8 +75,8 @@ def get(*args, **kwargs):
     console.echo(_get_information_about_a_cache(*args, **kwargs))
 
 
-def _list_caches_in_an_environment(username, password, mfa_secret, org, profile, environment, prefix=None, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, None).list_caches_in_an_environment(environment, prefix=prefix)
+def _list_caches_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, environment, prefix=None, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_caches_in_an_environment(environment, prefix=prefix)
 
 
 @caches.command(help='List caches in an environment.')
@@ -89,8 +89,8 @@ def list(*args, **kwargs):
     console.echo(_list_caches_in_an_environment(*args, **kwargs))
 
 
-def _update_a_cache_in_an_environment(username, password, mfa_secret, org, profile, name, environment, body, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).update_a_cache_in_an_environment(environment, body).text
+def _update_a_cache_in_an_environment(username, password, mfa_secret, token, zonename, org, profile, name, environment, body, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).update_a_cache_in_an_environment(environment, body).text
 
 
 @caches.command(
@@ -106,8 +106,8 @@ def update(*args, **kwargs):
     console.echo(_update_a_cache_in_an_environment(*args, **kwargs))
 
 
-def _delete_a_cache(username, password, mfa_secret, org, profile, name, environment, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, name).delete_a_cache(environment).text
+def _delete_a_cache(username, password, mfa_secret, token, zonename, org, profile, name, environment, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_a_cache(environment).text
 
 
 @caches.command(help='Deletes a cache.')
@@ -120,8 +120,8 @@ def delete(*args, **kwargs):
     console.echo(_delete_a_cache(*args, **kwargs))
 
 
-def _push_cache(username, password, mfa_secret, org, profile, environment, file, **kwargs):
-    return Caches(gen_auth(username, password, mfa_secret), org, None).push_cache(environment, file)
+def _push_cache(username, password, mfa_secret, token, zonename, org, profile, environment, file, **kwargs):
+    return Caches(gen_auth(username, password, mfa_secret, token, zonename), org, None).push_cache(environment, file)
 
 
 @caches.command(help='Push Cache to Apigee. This will create/update a Cache.')
