@@ -16,8 +16,8 @@ def userroles():
     pass
 
 
-def _add_a_user_to_a_role(username, password, mfa_secret, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).add_a_user_to_a_role(user_email).text
+def _add_a_user_to_a_role(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_a_user_to_a_role(user_email).text
 
 
 @userroles.command(help='Add a user to a role.')
@@ -30,8 +30,8 @@ def add_user(*args, **kwargs):
     console.echo(_add_a_user_to_a_role(*args, **kwargs))
 
 
-def _add_permissions_for_a_resource_to_a_user_role(username, password, mfa_secret, org, profile, name, body, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).add_permissions_for_a_resource_to_a_user_role(body).text
+def _add_permissions_for_a_resource_to_a_user_role(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_permissions_for_a_resource_to_a_user_role(body).text
 
 
 @userroles.command(help='Add Permissions for Resource to a Role')
@@ -44,8 +44,8 @@ def add_permissions(*args, **kwargs):
     console.echo(_add_permissions_for_a_resource_to_a_user_role(*args, **kwargs))
 
 
-def _add_permissions_for_multiple_resources_to_a_user_role(username, password, mfa_secret, org, profile, name, body, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).add_permissions_for_multiple_resources_to_a_user_role(body).text
+def _add_permissions_for_multiple_resources_to_a_user_role(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_permissions_for_multiple_resources_to_a_user_role(body).text
 
 
 @userroles.command(help='Adds multiple permissions to multiple resources simultaneously.')
@@ -58,8 +58,8 @@ def add_permissions_multiple(*args, **kwargs):
     console.echo(_add_permissions_for_multiple_resources_to_a_user_role(*args, **kwargs))
 
 
-def _create_a_user_role_in_an_organization(username, password, mfa_secret, org, profile, names, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, names).create_a_user_role_in_an_organization().text
+def _create_a_user_role_in_an_organization(username, password, mfa_secret, token, zonename, org, profile, names, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, names).create_a_user_role_in_an_organization().text
 
 
 @userroles.command(help='Creates one or more user roles in an organization.')
@@ -71,8 +71,8 @@ def create(*args, **kwargs):
     console.echo(_create_a_user_role_in_an_organization(*args, **kwargs))
 
 
-def _delete_a_permission_for_a_resource(username, password, mfa_secret, org, profile, name, permission, resource_path, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).delete_a_permission_for_a_resource(permission, resource_path).text
+def _delete_a_permission_for_a_resource(username, password, mfa_secret, token, zonename, org, profile, name, permission, resource_path, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_a_permission_for_a_resource(permission, resource_path).text
 
 
 @userroles.command(
@@ -88,8 +88,8 @@ def delete_permission(*args, **kwargs):
     console.echo(_delete_a_permission_for_a_resource(*args, **kwargs))
 
 
-def _delete_resource_from_permissions(username, password, mfa_secret, org, profile, name, resource_path, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).delete_resource_from_permissions(resource_path).text
+def _delete_resource_from_permissions(username, password, mfa_secret, token, zonename, org, profile, name, resource_path, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_resource_from_permissions(resource_path).text
 
 
 @userroles.command(help='Removes all permissions for a resource for the role specified. Permissions are case sensitive.')
@@ -102,8 +102,8 @@ def delete_resource(*args, **kwargs):
     console.echo(_delete_resource_from_permissions(*args, **kwargs))
 
 
-def _delete_a_user_role(username, password, mfa_secret, org, profile, name, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).delete_a_user_role().text
+def _delete_a_user_role(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_a_user_role().text
 
 
 @userroles.command(help='Deletes a role from an organization. Roles can only be deleted when no users are in the role.')
@@ -115,8 +115,8 @@ def delete(*args, **kwargs):
     console.echo(_delete_a_user_role(*args, **kwargs))
 
 
-def _get_a_role(username, password, mfa_secret, org, profile, name, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).get_a_role().text
+def _get_a_role(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_a_role().text
 
 
 @userroles.command(help='Gets the name of a user role.')
@@ -128,8 +128,12 @@ def get(*args, **kwargs):
     console.echo(_get_a_role(*args, **kwargs))
 
 
-def _get_resource_permissions_for_a_specific_role(username, password, mfa_secret, org, profile, name, resource_path="", **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).get_resource_permissions_for_a_specific_role(resource_path=resource_path).text
+def _get_resource_permissions_for_a_specific_role(username, password, mfa_secret, token, zonename, org, profile, name, resource_path="", **kwargs):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_resource_permissions_for_a_specific_role(resource_path=resource_path)
+        .text
+    )
 
 
 @userroles.command(help='Gets a list of permissions associated with the specified resource.')
@@ -142,8 +146,8 @@ def get_permissions(*args, **kwargs):
     console.echo(_get_resource_permissions_for_a_specific_role(*args, **kwargs))
 
 
-def _get_users_for_a_role(username, password, mfa_secret, org, profile, name, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).get_users_for_a_role().text
+def _get_users_for_a_role(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_users_for_a_role().text
 
 
 @userroles.command(help='Returns a list of all system users associated with a role.')
@@ -155,8 +159,8 @@ def get_users(*args, **kwargs):
     console.echo(_get_users_for_a_role(*args, **kwargs))
 
 
-def _list_permissions_for_a_resource(username, password, mfa_secret, org, profile, name, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).list_permissions_for_a_resource().text
+def _list_permissions_for_a_resource(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).list_permissions_for_a_resource().text
 
 
 @userroles.command(help='Gets permissions for all resources associated with a user role.')
@@ -168,8 +172,8 @@ def list_permissions(*args, **kwargs):
     console.echo(_list_permissions_for_a_resource(*args, **kwargs))
 
 
-def _list_user_roles(username, password, mfa_secret, org, profile, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, None).list_user_roles().text
+def _list_user_roles(username, password, mfa_secret, token, zonename, org, profile, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_user_roles().text
 
 
 @userroles.command(help='Gets a list of roles available to users in an organization.')
@@ -181,8 +185,8 @@ def list(*args, **kwargs):
     console.echo(_list_user_roles(*args, **kwargs))
 
 
-def _remove_user_membership_in_role(username, password, mfa_secret, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).remove_user_membership_in_role(user_email).text
+def _remove_user_membership_in_role(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).remove_user_membership_in_role(user_email).text
 
 
 @userroles.command(help='Remove user membership in role.')
@@ -195,9 +199,11 @@ def remove_user(*args, **kwargs):
     console.echo(_remove_user_membership_in_role(*args, **kwargs))
 
 
-def _verify_a_user_roles_permission_on_a_specific_RBAC_resource(username, password, mfa_secret, org, profile, name, permission, resource_path, **kwargs):
+def _verify_a_user_roles_permission_on_a_specific_RBAC_resource(
+    username, password, mfa_secret, token, zonename, org, profile, name, permission, resource_path, **kwargs
+):
     return (
-        Userroles(gen_auth(username, password, mfa_secret), org, name)
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
         .verify_a_user_roles_permission_on_a_specific_RBAC_resource(permission, resource_path)
         .text
     )
@@ -214,8 +220,8 @@ def verify_permission(*args, **kwargs):
     console.echo(_verify_a_user_roles_permission_on_a_specific_RBAC_resource(*args, **kwargs))
 
 
-def _verify_user_role_membership(username, password, mfa_secret, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret), org, name).verify_user_role_membership(user_email).text
+def _verify_user_role_membership(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
+    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).verify_user_role_membership(user_email).text
 
 
 @userroles.command(help='Verify user role membership.')
